==> JobOffers-0.2.0-py2.py3-none-any.whl: job_offers/views.py <==
# -*- coding: utf-8 -*-

import importlib

from django.views.generic.base import TemplateResponseMixin, View
from django.views.generic.list import MultipleObjectMixin
from django.views.generic.edit import FormMixin, CreateView, UpdateView
from django.core.urlresolvers import reverse_lazy
from django.core import mail
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from django.test.signals import setting_changed
from django.dispatch import receiver

from job_offers.forms import ApplicationForm, SearchForm
from job_offers.models import JobOffer
from job_offers.helpers import SearchFormHelper, ApplicationFormHelper
from job_offers.mails import (
    JobOfferConfirmationMail,
    SpecApplicationConfirmationMail,
    AdminNotificationMail,
)


_form_helper_module = uninitialized = object()

@receiver(setting_changed)
def on_setting_changed(sender, setting, **kw):
    global _form_helper_module
    if setting == 'JOB_OFFER_HELPERS_MODULE':
        _form_helper_module = uninitialized


def get_form_helper_module():
    global _form_helper_module
    if _form_helper_module is uninitialized:
        module_name = getattr(settings, 'JOB_OFFER_HELPERS_MODULE', None)
        if module_name is not None:
            _form_helper_module = importlib.import_module(module_name)
    return _form_helper_module


class FormHelperMixin(object):
    form_helper_class = None

    def get_form_helper_class(self):
        if self.form_helper_class is None:
            raise ImproperlyConfigured('Missing form_helper_class attribute on class {}'.format(self.__class__))

        module = get_form_helper_module()
        try:
            return getattr(module, self.form_helper_class.__name__)
        except AttributeError:
            pass
        return self.form_helper_class

    def get_form_helper(self):
        helper_class = self.get_form_helper_class()
        kwargs = self.get_form_helper_kwargs()
        return helper_class(**kwargs)

    def get_form_helper_kwargs(self):
        return {}

    def get_context_data(self, **kw):
        context = super(FormHelperMixin, self).get_context_data(**kw)
        context.update({
            'form_helper': self.get_form_helper(),
        })
        return context


class HomeView(MultipleObjectMixin, TemplateResponseMixin, FormHelperMixin, FormMixin, View):
    form_class = SearchForm
    queryset = JobOffer.objects.active()
    template_name = 'job_offers/list.html'
    paginate_by = 10
    form_helper_class = SearchFormHelper

    def get_form_kwargs(self):
        kwargs = super(HomeView, self).get_form_kwargs()
        if self.request.GET:
            kwargs['data'] = self.request.GET
        return kwargs

    def get_context_data(self, **kw):
        context = super(HomeView, self).get_context_data(**kw)
        context.update({
            'form': self.form,
        })
        return context

    def get(self, request, *args, **kw):
        self.form = self.get_form()

        if self.form.is_bound and self.form.is_valid():
            self.predicates = self.form.cleaned_data
        else:
            self.predicates = {}

        self.object_list = self.get_queryset()
        context = self.get_context_data()

        self.request.session['job-offers'] = [x.pk for x in self.object_list]
        return self.render_to_response(context)

    def get_queryset(self):
        qs = super(HomeView, self).get_queryset()

        if self.predicates.get('keywords'):
            qs = qs.filter_by_keywords(self.predicates['keywords'])
        if self.predicates.get('location'):
            qs = qs.filter(location=self.predicates['location'])
        if self.predicates.get('contract_type'):
            qs = qs.filter(contract_type__title=self.predicates['contract_type'])
        if self.predicates.get('business_unit'):
            qs = qs.filter(business_unit=self.predicates['business_unit'])
        if self.predicates.get('sector'):
            qs = qs.filter(business_unit=self.predicates['sector'])

        if self.predicates.get('order'):
            qs = qs.order_by(self.predicates['order'])
            if self.predicates.get('reverse'):
                qs = qs.reverse()
        return qs


class JobView(FormHelperMixin, UpdateView):
    """Job detail view"""
    queryset = JobOffer.objects.all()
    template_name = 'job_offers/job.html'
    form_class = ApplicationForm
    success_url = reverse_lazy('job-offer-success')
    context_object_name = 'job_offer'
    form_helper_class = ApplicationFormHelper

    def get_context_data(self, **kw):
        context = super(JobView, self).get_context_data(**kw)
        context.update({
            'previous': self._get_previous(),
            'next': self._get_next(),
        })
        return context

    def get_form_kwargs(self):
        kwargs = super(JobView, self).get_form_kwargs()
        kwargs['instance'] = None
        return kwargs

    def _get_sibling_offer(self, inc):
        job_offers = self.request.session.get('job-offers')
        if not job_offers:
            return None
        try:
            index = job_offers.index(self.object.pk) + inc
        except ValueError:
            return None

        if 0 > index or index >= len(job_offers):
            return None
        try:
            return JobOffer.objects.active().get(pk=job_offers[index])
        except JobOffer.DoesNotExist:
            return None

    def _get_next(self):
        return self._get_sibling_offer(+1)

    def _get_previous(self):
        return self._get_sibling_offer(-1)

    def form_valid(self, form):
        resp = super(JobView, self).form_valid(form)

        mails = []

        jocm = JobOfferConfirmationMail()
        mails.append(jocm.get_email(self.object))

        anm = AdminNotificationMail()
        mails.append(anm.get_email(self.object))

        with mail.get_connection() as connection:
            connection.send_messages(mails)

        return resp


class SpecApplicationView(FormHelperMixin, CreateView):
    template_name = 'job_offers/speculative_application.html'
    form_class = ApplicationForm
    success_url = reverse_lazy('job-offer-success')
    form_helper_class = ApplicationFormHelper

    def form_valid(self, form):
        resp = super(SpecApplicationView, self).form_valid(form)

        mails = []

        facm = SpecApplicationConfirmationMail()
        mails.append(facm.get_email(self.object))

        anm = AdminNotificationMail()
        mails.append(anm.get_email(self.object))

        with mail.get_connection() as connection:
            connection.send_messages(mails)

        return resp

==> JobOffers-0.3.0-py2.py3-none-any.whl: job_offers/views.py <==
# -*- coding: utf-8 -*-

import importlib

from django.views.generic.base import TemplateResponseMixin, View
from django.views.generic.list import MultipleObjectMixin
from django.views.generic.edit import FormMixin, CreateView, UpdateView
from django.core.urlresolvers import reverse_lazy
from django.core import mail
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from django.test.signals import setting_changed
from django.dispatch import receiver

from job_offers.forms import ApplicationForm, SearchForm
from job_offers.models import JobOffer
from job_offers.helpers import SearchFormHelper, ApplicationFormHelper
from job_offers.mails import (
    JobOfferConfirmationMail,
    SpecApplicationConfirmationMail,
    AdminNotificationMail,
)


_form_helper_module = uninitialized = object()


@receiver(setting_changed)
def on_setting_changed(sender, setting, **kw):
    global _form_helper_module
    if setting == 'JOB_OFFER_HELPERS_MODULE':
        _form_helper_module = uninitialized


def get_form_helper_module():
    global _form_helper_module
    if _form_helper_module is uninitialized:
        module_name = getattr(settings, 'JOB_OFFER_HELPERS_MODULE', None)
        if module_name is not None:
            _form_helper_module = importlib.import_module(module_name)
    return _form_helper_module


class FormHelperMixin(object):
    form_helper_class = None

    def get_form_helper_class(self):
        if self.form_helper_class is None:
            raise ImproperlyConfigured('Missing form_helper_class attribute on class {}'.format(self.__class__))

        module = get_form_helper_module()
        try:
            return getattr(module, self.form_helper_class.__name__)
        except AttributeError:
            pass
        return self.form_helper_class

    def get_form_helper(self):
        helper_class = self.get_form_helper_class()
        kwargs = self.get_form_helper_kwargs()
        return helper_class(**kwargs)

    def get_form_helper_kwargs(self):
        return {}

    def get_context_data(self, **kw):
        context = super(FormHelperMixin, self).get_context_data(**kw)
        context.update({
            'form_helper': self.get_form_helper(),
        })
        return context


class HomeView(MultipleObjectMixin, TemplateResponseMixin, FormHelperMixin, FormMixin, View):
    form_class = SearchForm
    queryset = JobOffer.objects.active()
    template_name = 'job_offers/list.html'
    paginate_by = 50
    form_helper_class = SearchFormHelper
    context_object_name = 'job_offers'

    def get_form_kwargs(self):
        kwargs = super(HomeView, self).get_form_kwargs()
        if self.request.GET:
            kwargs['data'] = self.request.GET
        return kwargs

    def get_context_data(self, **kw):
        context = super(HomeView, self).get_context_data(**kw)
        context.update({
            'form': self.form,
        })
        return context

    def get(self, request, *args, **kw):
        self.form = self.get_form()

        queryset = self.get_queryset()
        if self.form.is_bound and self.form.is_valid():
            predicates = self.form.get_predicates()
            order_by = self.form.get_order_by()
            queryset = queryset.filter(predicates).order_by(order_by)
        self.object_list = queryset

        context = self.get_context_data()
        self.request.session['job-offers'] = [x.pk for x in self.object_list]
        return self.render_to_response(context)


class JobView(FormHelperMixin, UpdateView):
    """Job detail view"""
    queryset = JobOffer.objects.all()
    template_name = 'job_offers/job.html'
    form_class = ApplicationForm
    success_url = reverse_lazy('job-offer-success')
    context_object_name = 'job_offer'
    form_helper_class = ApplicationFormHelper

    def get_context_data(self, **kw):
        context = super(JobView, self).get_context_data(**kw)
        context.update({
            'previous': self._get_previous(),
            'next': self._get_next(),
        })
        return context

    def get_form_kwargs(self):
        kwargs = super(JobView, self).get_form_kwargs()
        kwargs['instance'] = None
        return kwargs

    def _get_sibling_offer(self, inc):
        job_offers = self.request.session.get('job-offers')
        if not job_offers:
            return None
        try:
            index = job_offers.index(self.object.pk) + inc
        except ValueError:
            return None

        if 0 > index or index >= len(job_offers):
            return None
        try:
            return JobOffer.objects.active().get(pk=job_offers[index])
        except JobOffer.DoesNotExist:
            return None

    def _get_next(self):
        return self._get_sibling_offer(+1)

    def _get_previous(self):
        return self._get_sibling_offer(-1)

    def form_valid(self, form):
        resp = super(JobView, self).form_valid(form)

        mails = []

        jocm = JobOfferConfirmationMail()
        mails.append(jocm.get_email(self.object))

        anm = AdminNotificationMail()
        mails.append(anm.get_email(self.object))

        with mail.get_connection() as connection:
            connection.send_messages(mails)

        return resp


class SpecApplicationView(FormHelperMixin, CreateView):
    template_name = 'job_offers/speculative_application.html'
    form_class = ApplicationForm
    success_url = reverse_lazy('job-offer-success')
    form_helper_class = ApplicationFormHelper

    def form_valid(self, form):
        resp = super(SpecApplicationView, self).form_valid(form)

        mails = []

        facm = SpecApplicationConfirmationMail()
        mails.append(facm.get_email(self.object))

        anm = AdminNotificationMail()
        mails.append(anm.get_email(self.object))

        with mail.get_connection() as connection:
            connection.send_messages(mails)

        return resp
